//****************************************************************************
//	
//	Copyright 2017 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : flash.cpp
//
//	Project	 : PCM-UIO48/96 Console Application
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	08/15/17	  1.0		Original Release
//
//****************************************************************************

#include <stdio.h>
#include <stdlib.h>  
#include <tchar.h>  
#include <windows.h>
#include "pcmuio48DLL.h"

#define MAJOR_VER   1
#define MINOR_VER   0
#define MAX_DEV     2

int _tmain(int argc, _TCHAR* argv[])
{
    unsigned int portState[6] = { 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };  // define all as outputs
    int dllReturn = SUCCESS;

    printf("PCM-UIO48 Application : flash\n");
    printf("Version %d.%d\n\n", MAJOR_VER, MINOR_VER);

    for (int dev = 1; dev <= MAX_DEV; dev++)
    {
        dllReturn = InitializeSession(dev);

        if (dllReturn)
        {
            printf("Error initializing device %d.\n", dev);
            exit(dllReturn);
        }
        else   
        {
            printf("Device %d opened.\n", dev);
        }
    }

    for (int dev = 1; dev <= MAX_DEV; dev++)
    {
        dllReturn = SetIoMask(dev, portState);

        if (dllReturn)
        {
            printf("Error setting I/O mask for device %d.\n", dev);
            exit(dllReturn);
        }
    }

    for (int dev = 1; dev <= MAX_DEV; dev++)
    {
        printf("Flashing bits for device %d...\n", dev);

        for (int bit = 0; bit < 48; bit++)
        {
           dllReturn = SetBit(dev, bit);

           if (dllReturn)
           {
               printf("\nError setting bit %d on device %d.\n", bit, dev);
               break;
           }

           Sleep(200);

           if (ClearBit(dev, bit))
           {
               printf("\nError clearing bit %d on device %d.\n", bit, dev);
               break;
           }

           Sleep(200);
        }
    }

    for (int dev = 1; dev <= MAX_DEV; dev++)
    {
        dllReturn = CloseSession(dev);

        if (dllReturn)
        {
            printf("Error closing device %d.\n", dev);
            exit(dllReturn);
        }
        else
        {
            printf("Device %d closed.\n", dev);
        }
    }

    return(0);
}
